<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi_FI" version="2.0">
<context>
    <name>Badges</name>
    <message>
        <location filename="../qml/pages/Badges.qml" line="18"/>
        <source>BADGES</source>
        <translation>ANSIOMERKIT</translation>
    </message>
</context>
<context>
    <name>Checkin</name>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="18"/>
        <source>CHECK-IN DETAILS</source>
        <translation>CHECK-IN TIEDOT</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="223"/>
        <source>TOTAL POINTS</source>
        <translation>PISTEET</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="261"/>
        <source>EARNED BADGES</source>
        <translation>ANSAITUT ARVOMERKIT</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="283"/>
        <source>COMMENTS</source>
        <translation>KOMMENTIT</translation>
    </message>
</context>
<context>
    <name>CheckinDialog</name>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="22"/>
        <source>NEW CHECK-IN</source>
        <translation>UUSI CHECK-IN</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="48"/>
        <source>CHECK IN</source>
        <translation>CHECK-IN</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="57"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="100"/>
        <source>Whats on your mind?</source>
        <translation>Mitä mietit?</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="129"/>
        <source>Sharing options</source>
        <translation>Jakamisen asetukset</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="133"/>
        <source>Share with Friends</source>
        <translation>Jaa kavereiden kanssa</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="141"/>
        <source>Post to Facebook</source>
        <translation>Jaa Facebookiin</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="149"/>
        <source>Post to Twitter</source>
        <translation>Jaa Twitteriin</translation>
    </message>
</context>
<context>
    <name>CheckinHistory</name>
    <message>
        <location filename="../qml/pages/CheckinHistory.qml" line="24"/>
        <source>CHECK-IN HISTORY</source>
        <translation>CHECK-IN-HISTORIA</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinHistory.qml" line="64"/>
        <source>Load More</source>
        <translation>Lataa lisää</translation>
    </message>
</context>
<context>
    <name>CommentDialog</name>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="26"/>
        <source>What is on your mind?</source>
        <translation>Mitä mietit?</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="38"/>
        <source>New awesome comment</source>
        <translation>Uusi loistava kommentti</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="69"/>
        <source>Comment!</source>
        <translation>Kommentoi!</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="77"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
</context>
<context>
    <name>DebugSubmit</name>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="18"/>
        <source>DEBUG SUBMIT</source>
        <translation>LÄHETÄ DEBUG-TIEDOT</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="34"/>
        <source>Thank you for submit!&lt;br&gt;This will be implemented soon!</source>
        <translation>Kiitos tiedoista!&lt;br&gt;Tämä ominaisuus lisätään pian!</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="53"/>
        <source>SUBMIT</source>
        <translation>LÄHETÄ</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="61"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="92"/>
        <source>You can help me with Nelisquare development by submitting debug info.

The following information are going to be submitted:</source>
        <translation>Voit auttaa Nelisquaren kehityksessä lähettämällä debug-tiedot.

Seuraavat tiedot lähetään:</translation>
    </message>
</context>
<context>
    <name>DebugWidget</name>
    <message>
        <location filename="../qml/components/DebugWidget.qml" line="14"/>
        <source>Unknown %1 event!</source>
        <translation>Tuntematon %1 tapahtuma!</translation>
    </message>
    <message>
        <location filename="../qml/components/DebugWidget.qml" line="47"/>
        <source>This event type is unknown.
You can help with resolution.</source>
        <translation>Tapahtumalaji tuntematon.
Voit auttaa ongelman ratkaisussa.</translation>
    </message>
</context>
<context>
    <name>FriendsFeed</name>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="43"/>
        <source>FRIENDS FEED</source>
        <translation>SYÖTE</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="221"/>
        <source>RECENT</source>
        <translation>VIIMEISIMMÄT</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="234"/>
        <source>NEARBY</source>
        <translation>LÄHISTÖLLÄ</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="255"/>
        <source>Load More</source>
        <translation>Lataa lisää</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="402"/>
        <source>Sorry, Pages are not supported yet :(</source>
        <translation>Pahoittelut, Sivut-ominaisuus ei ole vielä saatavilla :(</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="472"/>
        <source>Sorry, no lists support yet :(</source>
        <translation>Pahoittelut, Listat-ominaisuus ei ole vielä tuettu :(</translation>
    </message>
</context>
<context>
    <name>LeaderBoard</name>
    <message>
        <location filename="../qml/pages/LeaderBoard.qml" line="19"/>
        <source>YOU ARE #</source>
        <translation>OLET SIJALLA #</translation>
    </message>
    <message>
        <location filename="../qml/pages/LeaderBoard.qml" line="63"/>
        <source>&lt;b&gt;%1 points&lt;/b&gt; %2 checkins</source>
        <translation>&lt;b&gt;%1 pistettä&lt;/b&gt; %2 check-iniä</translation>
    </message>
</context>
<context>
    <name>LikeBox</name>
    <message>
        <location filename="../qml/components/LikeBox.qml" line="33"/>
        <source>USER LIKES</source>
        <translation>TYKKÄYKSET</translation>
    </message>
</context>
<context>
    <name>ListViewEx</name>
    <message>
        <location filename="../qml/components/ListViewEx.qml" line="9"/>
        <source>Pull and hold to refresh...</source>
        <translation>Vedä alas päivittääksesi...</translation>
    </message>
    <message>
        <location filename="../qml/components/ListViewEx.qml" line="10"/>
        <source>Release to refresh...</source>
        <translation>Vapauta päivittääksesi...</translation>
    </message>
</context>
<context>
    <name>Login24sq</name>
    <message>
        <location filename="../qml/pages/Login24sq.qml" line="42"/>
        <source>Sign In to Foursquare</source>
        <translation>Kirjaudu Foursquareen</translation>
    </message>
</context>
<context>
    <name>Mayorships</name>
    <message>
        <location filename="../qml/pages/Mayorships.qml" line="19"/>
        <source>MAYORSHIPS</source>
        <translation>PORMESTARIUDET</translation>
    </message>
</context>
<context>
    <name>NotificationDialog</name>
    <message>
        <location filename="../qml/components/NotificationDialog.qml" line="36"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Notifications</name>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="24"/>
        <source>NOTIFICATIONS</source>
        <translation>ILMOITUKSET</translation>
    </message>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="51"/>
        <source>Mark all as read</source>
        <translation>Merkitse kaikki luetuiksi</translation>
    </message>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="58"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
</context>
<context>
    <name>PageWrapper</name>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="88"/>
        <source>Check updates</source>
        <translation>Tarkista päivitykset</translation>
    </message>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="94"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="100"/>
        <source>Exit</source>
        <translation>Sulje</translation>
    </message>
</context>
<context>
    <name>Photo</name>
    <message>
        <location filename="../qml/pages/Photo.qml" line="20"/>
        <source>PHOTO</source>
        <translation>KUVA</translation>
    </message>
</context>
<context>
    <name>PhotoAdd</name>
    <message>
        <location filename="../qml/pages/PhotoAdd.qml" line="18"/>
        <source>Select photo for upload</source>
        <translation>Valitse ladattava kuva</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoAdd.qml" line="56"/>
        <source>Error uploading photo!</source>
        <translation>Virhe ladattaessa kuvaa!</translation>
    </message>
</context>
<context>
    <name>PhotoShareDialog</name>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="20"/>
        <source>PHOTO UPLOAD</source>
        <translation>KUVAN LATAAMINEN</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="36"/>
        <source>UPLOAD</source>
        <translation>LATAA</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="86"/>
        <source>Sharing options</source>
        <translation>Jakamisen asetukset</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="90"/>
        <source>Public</source>
        <translation>Julkinen</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="97"/>
        <source>Post to Facebook</source>
        <translation>Jaa Facebookiin</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="104"/>
        <source>Post to Twitter</source>
        <translation>Jaa Twitteriin</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="48"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
</context>
<context>
    <name>PhotosBox</name>
    <message>
        <location filename="../qml/components/PhotosBox.qml" line="8"/>
        <source>PHOTOS</source>
        <translation>KUVAT</translation>
    </message>
</context>
<context>
    <name>PhotosGallery</name>
    <message>
        <location filename="../qml/pages/PhotosGallery.qml" line="13"/>
        <source>VENUE PHOTOS</source>
        <translation>KOHTEEN KUVAT</translation>
    </message>
</context>
<context>
    <name>SettingSlider</name>
    <message>
        <location filename="../qml/components/SettingSlider.qml" line="50"/>
        <source>Off</source>
        <translation>Pois</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../qml/pages/Settings.qml" line="13"/>
        <source>updating...</source>
        <translation>päivitetään...</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="21"/>
        <source>SETTINGS</source>
        <translation>ASETUKSET</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="53"/>
        <source>2012-2013 Basil Semuonov</source>
        <translation>2012-2013 Basil Semuonov</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="54"/>
        <source>Idea by Tommi Laukkanen</source>
        <translation>Alkuperäisidea Tommi Laukkanen</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="55"/>
        <source>Shout out to @knobtviker</source>
        <translation>Twiittaa @knobtviker</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="56"/>
        <source>Design by Kim Venetvirta</source>
        <translation>Ulkoasu Kim Venetvirta</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="57"/>
        <source>If any problems, tweet @basil_s</source>
        <translation>Ongelmatilanteissa twiittaa @basil_s</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="58"/>
        <source>Version</source>
        <translation>Versio</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="60"/>
        <source>Build</source>
        <translation>Koontiversio</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="62"/>
        <source>Powered by Foursquare</source>
        <translation>Powered by Foursquare</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="64"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="70"/>
        <location filename="../qml/pages/Settings.qml" line="115"/>
        <source>Reset settings</source>
        <translation>Nollaa asetukset</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="71"/>
        <source>This action will erase all data including auth token, application settings and cache.</source>
        <translation>Tämä poistaa kaikki tiedot sisältäen valtuutusluvan, sovellusasetukset ja välimuistin.</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="72"/>
        <source>Yes, clear the data</source>
        <translation>Kyllä, pyyhi tiedot</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="73"/>
        <source>No, thanks</source>
        <translation>Ei kiitos</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="81"/>
        <source>Language</source>
        <translation>Kieli</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="109"/>
        <source>Notifications</source>
        <translation>Ilmoitukset</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="161"/>
        <source>UPDATES CHECK</source>
        <translation>PÄIVITYKSET</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="186"/>
        <source>None</source>
        <translation>Ei</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="192"/>
        <source>Stable</source>
        <translation>Vakaa</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="197"/>
        <source>Beta</source>
        <translation>Beta</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="203"/>
        <source>Alpha</source>
        <translation>Alfa</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="209"/>
        <source>INTERVALS</source>
        <translation>AIKARAJAT</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="213"/>
        <source>GPS Unlock timeout</source>
        <translation>GPS päällä, kun sovellus taustalla</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="214"/>
        <source>Instant</source>
        <translation>Heti</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="214"/>
        <source>%1 secs(s)</source>
        <translation>%1 s</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="214"/>
        <location filename="../qml/pages/Settings.qml" line="223"/>
        <source>Disabled</source>
        <translation>Pois käytöstä</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="222"/>
        <source>Feed autoupdate time</source>
        <translation>Syötteen automaattinen päivitys</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="223"/>
        <source>Off</source>
        <translation>Pois</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="223"/>
        <source>%1 min(s)</source>
        <translation>%1 min</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="231"/>
        <source>PERMISSIONS</source>
        <translation>LISÄASETUKSET</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="234"/>
        <source>Allow use of Location Data</source>
        <translation>Salli paikkatietojen käyttö</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="242"/>
        <source>Always run in background</source>
        <translation>Suorita sovellus taustalla</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="250"/>
        <source>Enable notifications</source>
        <translation>Aktivoi ilmoitukset</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="258"/>
        <source>Feed at Home screen</source>
        <translation>Alotusnäytön syöte</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="266"/>
        <source>Push notifications</source>
        <translation>Push-ilmoitukset</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="317"/>
        <source>COLOR THEME</source>
        <translation>TEEMA</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="336"/>
        <source>Light</source>
        <translation>Vaalea</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="342"/>
        <source>Dark</source>
        <translation>Tumma</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="348"/>
        <source>SCREEN ORIENTATION</source>
        <translation>NÄYTÖN SUUNTA</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="370"/>
        <source>Auto</source>
        <translation>Vapaa</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="376"/>
        <source>Landscape</source>
        <translation>Vaaka</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="381"/>
        <source>Portrait</source>
        <translation>Pysty</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="387"/>
        <source>STARTUP PAGE</source>
        <translation>ALOITUSSIVU</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="409"/>
        <source>Feed</source>
        <translation>Syöte</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="415"/>
        <source>Venues</source>
        <translation>Kohteet</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="420"/>
        <source>Self</source>
        <translation>Omat tiedot</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="426"/>
        <source>LANGUAGE</source>
        <translation>KIELI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="437"/>
        <source>MAP PROVIDER</source>
        <translation>KARTTOJEN TOIMITTAJA</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="460"/>
        <source>Nokia</source>
        <translation>Nokia</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="466"/>
        <source>Google</source>
        <translation>Google</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="471"/>
        <source>OSM</source>
        <translation>OSM</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="489"/>
        <source>IMAGE LOADING</source>
        <translation>KUVIEN LATAAMINEN</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="508"/>
        <source>All</source>
        <translation>Kaikki</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="513"/>
        <source>Cached</source>
        <translation>Välimuisti</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="519"/>
        <source>INTEGRATION WITH APPS</source>
        <translation>YHDISTÄ MUIHIN SOVELLUKSIIN</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="525"/>
        <source>Download MOLO.ME</source>
        <translation>Lataa MOLO.ME</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="544"/>
        <source>MOLO.ME Photos</source>
        <translation>MOLO.ME-kuvat</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="564"/>
        <source>APPLICATION CACHE</source>
        <translation>SOVELLUKSEN VÄLIMUISTI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="572"/>
        <source>Clear</source>
        <translation>Tyhjennä</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="584"/>
        <source>Size: %1</source>
        <translation>Koko: %1</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="590"/>
        <source>UI</source>
        <translation>KÄYTTÖLIITTYMÄ</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="593"/>
        <source>Reload UI</source>
        <translation>Lataa käyttöliittymä uudelleen</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="599"/>
        <source>AUTHENTICATION</source>
        <translation>TODENNUS</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="602"/>
        <source>Reset authentication</source>
        <translation>Nollaa todennustiedot</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="623"/>
        <source>ACCESS RATE LIMIT</source>
        <translation>ACCESS RATE LIMIT</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="629"/>
        <source>API requests available: %1 / %2</source>
        <translation>API-pyyntöjä saatavilla: %1 / %2</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="635"/>
        <source>You are low on X-RATE requests</source>
        <translation>Sinulla on vähän X-RATE pyyntöjä</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="640"/>
        <source>DEBUG</source>
        <translation>DEBUG</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="643"/>
        <source>Enable debug</source>
        <translation>Aktivoi debug-ominaisuudet</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="657"/>
        <source>Options will be available soon</source>
        <translation>Asetukset ovat saatavilla pian</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="672"/>
        <source>General</source>
        <translation>Yleiset</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="673"/>
        <source>Theme</source>
        <translation>Teema</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="674"/>
        <source>Service</source>
        <translation>Palvelu</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="675"/>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
</context>
<context>
    <name>SpecialsList</name>
    <message>
        <location filename="../qml/components/SpecialsList.qml" line="13"/>
        <source>VENUE SPECIALS</source>
        <translation>KOHTEEN TARJOUKSET</translation>
    </message>
    <message>
        <location filename="../qml/components/SpecialsList.qml" line="31"/>
        <source>Unlocked!</source>
        <translation>Avattu!</translation>
    </message>
</context>
<context>
    <name>TipDialog</name>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="40"/>
        <source>Write some cool tip here</source>
        <translation>Jätä loistava vinkki</translation>
    </message>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="71"/>
        <source>ADD</source>
        <translation>LISÄÄ</translation>
    </message>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="79"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
</context>
<context>
    <name>TipPage</name>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="22"/>
        <source>Usefull tip</source>
        <translation>Hyödyllinen vinkki</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="149"/>
        <source>TIP PHOTO</source>
        <translation>VINKIN KUVA</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="171"/>
        <source>Save tip</source>
        <translation>Tallenna vinkki</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="179"/>
        <source>Mark as done</source>
        <translation>Merkitse tehdyksi</translation>
    </message>
</context>
<context>
    <name>TipsList</name>
    <message>
        <location filename="../qml/pages/TipsList.qml" line="18"/>
        <source>TIPS LIST</source>
        <translation>VINKKILISTA</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="12"/>
        <source>New update available</source>
        <translation>Päivitys saatavilla</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="13"/>
        <source>Version: %1&lt;br&gt;Type: %2&lt;br&gt;Build: %3&lt;br&gt;&lt;br&gt;Changelog: &lt;br&gt;%4</source>
        <translation>Versio: %1&lt;br&gt;Tyyppi: %2&lt;br&gt;Koontiversio: %3&lt;br&gt;&lt;br&gt;Muutosloki: &lt;br&gt;%4</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="19"/>
        <source>Update!</source>
        <translation>Päivitä!</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="20"/>
        <source>No, thanks</source>
        <translation>Ei kiitos</translation>
    </message>
</context>
<context>
    <name>User</name>
    <message>
        <location filename="../qml/pages/User.qml" line="59"/>
        <source>USER DETAILS</source>
        <translation>KÄYTTÄJÄTIEDOT</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="270"/>
        <source>Add Friend</source>
        <translation>Lisää kaveriksi</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="282"/>
        <source>Approve Friend</source>
        <translation>Hyväksy kaveripyyntö</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="289"/>
        <source>Deny friend</source>
        <translation>Hylkää kaveripyyntö</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="301"/>
        <source>Remove Friend</source>
        <translation>Poista kavereista</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="314"/>
        <source>&lt;b&gt;SCORES&lt;/b&gt; (LAST 7 DAYS)</source>
        <translation>&lt;b&gt;PISTEET&lt;/b&gt; (VIIMEISET 7 PÄIVÄÄ)</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="319"/>
        <source>BEST SCORE</source>
        <translation>PARAS TULOS</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="377"/>
        <source>Badges</source>
        <translation>ansiomerkkiä</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="412"/>
        <source>Checkins</source>
        <translation>check-iniä</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="447"/>
        <source>Mayorships</source>
        <translation>pormestariutta</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="482"/>
        <source>Friends</source>
        <translation>kaveria</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="517"/>
        <source>Photos</source>
        <translation>kuvaa</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="553"/>
        <source>Tips</source>
        <translation>vinkkiä</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="569"/>
        <source>YOU ARE #</source>
        <translation>OLET SIJALLA #</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="594"/>
        <source>&lt;b&gt;%1 points&lt;/b&gt; %2 checkins</source>
        <translation>&lt;b&gt;%1 pistettä&lt;/b&gt; %2 check-iniä</translation>
    </message>
</context>
<context>
    <name>UsersList</name>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="21"/>
        <source>Loading...</source>
        <translation>Ladataan...</translation>
    </message>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="30"/>
        <source>USER FRIENDS</source>
        <translation>KÄYTTÄJÄN KAVERIT</translation>
    </message>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="33"/>
        <source>LIKERS LIST</source>
        <translation>TYKKÄÄJÄT</translation>
    </message>
</context>
<context>
    <name>Venue</name>
    <message>
        <location filename="../qml/pages/Venue.qml" line="143"/>
        <source>VENUE PHOTOS</source>
        <translation>KOHTEEN KUVAT</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="251"/>
        <source>CHECK-IN HERE!</source>
        <translation>TEE CHECK-IN!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="273"/>
        <source>Venue doesn&apos;t have mayor yet!</source>
        <translation>Kohteella ei ole pormestaria vielä!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="274"/>
        <source>is the mayor.</source>
        <translation>on pormestari.</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="274"/>
        <source>It could be you!</source>
        <translation>Se voit olla sinä!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="275"/>
        <source>%1 checkins</source>
        <translation>%1 check-iniä</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="317"/>
        <source>BEST TIPS</source>
        <translation>PARHAAT VINKIT</translation>
    </message>
</context>
<context>
    <name>VenueAdd</name>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="91"/>
        <source>Venue name</source>
        <translation>Kohteen nimi</translation>
    </message>
</context>
<context>
    <name>VenueMap</name>
    <message>
        <location filename="../qml/pages/VenueMap.qml" line="186"/>
        <source>GET ROUTE</source>
        <translation>HANKI REITTIOHJEET</translation>
    </message>
</context>
<context>
    <name>VenuesList</name>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="21"/>
        <source>NEARBY VENUES</source>
        <translation>LÄHEISET KOHTEET</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="67"/>
        <source>GPS signal is fuzzy, cannot get your location</source>
        <translation>Häiriöitä GPS-signaalissa. Sijainnin määrittäminen ei onnistu.</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="96"/>
        <source>Tap to search place...</source>
        <translation>Hae...</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="107"/>
        <source>SEARCH</source>
        <translation>HAE</translation>
    </message>
</context>
<context>
    <name>Welcome</name>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="29"/>
        <source>Welcome!</source>
        <translation>Tervetuloa!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="46"/>
        <source>Please, login with Foursquare!</source>
        <translation>Ole hyvä ja kirjaudu Foursquareen!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="53"/>
        <source>Login</source>
        <translation>Kirjaudu</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="67"/>
        <source>Foursquare privacy policy</source>
        <translation>Foursquaren tietosuojakäytäntö</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="81"/>
        <source>Nelisquare privacy policy</source>
        <translation>Nelisquaren tietosuojakäytäntö</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="108"/>
        <source>Location data</source>
        <translation>Paikkatiedot</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="109"/>
        <source>Nelisquare requires use of user location data. Data is needed to make geo-location services work properly.</source>
        <translation>Nelisquaren käyttö vaatii käyttäjän paikkatietojen käyttöä. Tietoja tarvitaan, että paikkatietopalvelut toimivat oikein.</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="110"/>
        <source>Allow</source>
        <translation>Salli</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="111"/>
        <source>Deny</source>
        <translation>Kiellä</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="123"/>
        <source>Push notifications</source>
        <translation>Push-ilmoitukset</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="124"/>
        <source>Incoming push notifications are not supported at this version and are disabled by default.&lt;br/&gt;&lt;br/&gt;You will be promted again when they will be available at future versions.</source>
        <translation>Push-ilmoitukset eivät ole tuettuja tässä versiossa ja ne on poistettu käytöstä. &lt;br/&gt;&lt;br/&gt; Sinulle ilmoitetaan, kun ne ovat saatavilla.</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="128"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="161"/>
        <source>Check updates</source>
        <translation>Tarkista päivitykset</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="167"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="173"/>
        <source>Exit</source>
        <translation>Sulje</translation>
    </message>
</context>
</TS>